# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hvac.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import brick_pb2 as brick__pb2
from . import nullabletypes_pb2 as nullabletypes__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='hvac.proto',
  package='xbospb',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\nhvac.proto\x12\x06xbospb\x1a\x0b\x62rick.proto\x1a\x13nullabletypes.proto\"\xc3\x18\n\x03\x41HU\x12\x95\x01\n\"discharge_air_temperature_setpoint\x18\x01 \x01(\x0b\x32\x0e.xbospb.DoubleBY\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18$\x12\"Discharge_Air_Temperature_Setpoint\x12\x8d\x01\n\x1eoutside_air_temperature_sensor\x18\x02 \x01(\x0b\x32\x0e.xbospb.DoubleBU\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18 \x12\x1eOutside_Air_Temperature_Sensor\x12{\n\x15heating_valve_command\x18\x03 \x01(\x0b\x32\x0e.xbospb.DoubleBL\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\x17\x12\x15Heating_Valve_Command\x12\x99\x01\n$discharge_air_static_pressure_sensor\x18\x04 \x01(\x0b\x32\x0e.xbospb.DoubleB[\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18&\x12$Discharge_Air_Static_Pressure_Sensor\x12m\n\x0e\x63ooling_demand\x18\x05 \x01(\x0b\x32\x0e.xbospb.DoubleBE\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\x10\x12\x0e\x43ooling_Demand\x12{\n\x15\x63ooling_valve_command\x18\x06 \x01(\x0b\x32\x0e.xbospb.DoubleBL\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\x17\x12\x15\x43ooling_Valve_Command\x12\x89\x01\n\x1cmixed_air_temperature_sensor\x18\x07 \x01(\x0b\x32\x0e.xbospb.DoubleBS\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\x1e\x12\x1cMixed_Air_Temperature_Sensor\x12\x8f\x01\n\x1f\x62uilding_static_pressure_sensor\x18\x08 \x01(\x0b\x32\x0e.xbospb.DoubleBV\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18!\x12\x1f\x42uilding_Static_Pressure_Sensor\x12k\n\rfilter_status\x18\t \x01(\x0b\x32\x0e.xbospb.DoubleBD\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\x0f\x12\rFilter_Status\x12\x91\x01\n discharge_air_temperature_sensor\x18\n \x01(\x0b\x32\x0e.xbospb.DoubleBW\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\"\x12 Discharge_Air_Temperature_Sensor\x12\x93\x01\n!building_static_pressure_setpoint\x18\x0b \x01(\x0b\x32\x0e.xbospb.DoubleBX\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18#\x12!Building_Static_Pressure_Setpoint\x12\x9d\x01\n&discharge_air_static_pressure_setpoint\x18\x0c \x01(\x0b\x32\x0e.xbospb.DoubleB]\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18(\x12&Discharge_Air_Static_Pressure_Setpoint\x12s\n\x11occupancy_command\x18\r \x01(\x0b\x32\x0e.xbospb.DoubleBH\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\x13\x12\x11Occupancy_Command\x12\x8b\x01\n\x1dreturn_air_temperature_sensor\x18\x0e \x01(\x0b\x32\x0e.xbospb.DoubleBT\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\x1f\x12\x1dReturn_Air_Temperature_Sensor\x12\x7f\n\x17zone_temperature_sensor\x18\x0f \x01(\x0b\x32\x0e.xbospb.DoubleBN\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\x19\x12\x17Zone_Temperature_Sensor\x12\x9f\x01\n\'supply_air_damper_min_position_setpoint\x18\x10 \x01(\x0b\x32\x0e.xbospb.DoubleB^\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18)\x12\'Supply_Air_Damper_Min_Position_Setpoint\x12\x8d\x01\n\x1emixed_air_temperature_setpoint\x18\x11 \x01(\x0b\x32\x0e.xbospb.DoubleBU\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18 \x12\x1eMixed_Air_Temperature_Setpoint\x12y\n\x14occupied_mode_status\x18\x12 \x01(\x0b\x32\x0e.xbospb.DoubleBK\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\x16\x12\x14Occupied_Mode_Status\x12q\n\x10shutdown_command\x18\x13 \x01(\x0b\x32\x0e.xbospb.DoubleBG\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\x12\x12\x10Shutdown_Command\x12\xa1\x01\n(mixed_air_temperature_low_limit_setpoint\x18\x14 \x01(\x0b\x32\x0e.xbospb.DoubleB_\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18*\x12(Mixed_Air_Temperature_Low_Limit_Setpoint\x12\x83\x01\n\x19zone_temperature_setpoint\x18\x15 \x01(\x0b\x32\x0e.xbospb.DoubleBP\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\x1b\x12\x19Zone_Temperature_Setpoint\x12W\n\x03vav\x18\x16 \x01(\x0b\x32\x0e.xbospb.DoubleB:\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\x05\x12\x03VAV\x12W\n\x03vvt\x18\x17 \x01(\x0b\x32\x0e.xbospb.DoubleB:\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\x05\x12\x03VVT::\x82\xf1\x04-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xf1\x04\x05\x12\x03\x41HU\"\x83\x02\n\nEconomizer\x12\xb1\x01\n0economizer_differential_air_temperature_setpoint\x18\x01 \x01(\x0b\x32\x0e.xbospb.DoubleBg\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\x32\x12\x30\x45\x63onomizer_Differential_Air_Temperature_Setpoint:A\x82\xf1\x04-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xf1\x04\x0c\x12\nEconomizer\"\x8c\r\n\x03VAV\x12\x83\x01\n\x19zone_temperature_setpoint\x18\x01 \x01(\x0b\x32\x0e.xbospb.DoubleBP\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\x1b\x12\x19Zone_Temperature_Setpoint\x12\xab\x01\n-occupied_heating_min_supply_air_flow_setpoint\x18\x02 \x01(\x0b\x32\x0e.xbospb.DoubleBd\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18/\x12-Occupied_Heating_Min_Supply_Air_Flow_Setpoint\x12\x81\x01\n\x18supply_air_flow_setpoint\x18\x03 \x01(\x0b\x32\x0e.xbospb.DoubleBO\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\x1a\x12\x18Supply_Air_Flow_Setpoint\x12\x91\x01\n discharge_air_temperature_sensor\x18\x04 \x01(\x0b\x32\x0e.xbospb.DoubleBW\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\"\x12 Discharge_Air_Temperature_Sensor\x12m\n\x0eheating_demand\x18\x05 \x01(\x0b\x32\x0e.xbospb.DoubleBE\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\x10\x12\x0eHeating_Demand\x12\x61\n\x08\x62ox_mode\x18\x06 \x01(\x0b\x32\x0e.xbospb.DoubleB?\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\n\x12\x08\x42ox_Mode\x12m\n\x0e\x63ooling_demand\x18\x07 \x01(\x0b\x32\x0e.xbospb.DoubleBE\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\x10\x12\x0e\x43ooling_Demand\x12\x97\x01\n#supply_air_velocity_pressure_sensor\x18\x08 \x01(\x0b\x32\x0e.xbospb.DoubleBZ\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18%\x12#Supply_Air_Velocity_Pressure_Sensor\x12\x99\x01\n$cooling_max_supply_air_flow_setpoint\x18\t \x01(\x0b\x32\x0e.xbospb.DoubleB[\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18&\x12$Cooling_Max_Supply_Air_Flow_Setpoint\x12\x85\x01\n\x1athermostat_adjust_setpoint\x18\n \x01(\x0b\x32\x0e.xbospb.DoubleBQ\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\x1c\x12\x1aThermostat_Adjust_Setpoint\x12\x7f\n\x17zone_temperature_sensor\x18\x0b \x01(\x0b\x32\x0e.xbospb.DoubleBN\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\x19\x12\x17Zone_Temperature_Sensor\x12}\n\x16supply_air_flow_sensor\x18\x0c \x01(\x0b\x32\x0e.xbospb.DoubleBM\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\x18\x12\x16Supply_Air_Flow_Sensor::\x82\xf1\x04-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xf1\x04\x05\x12\x03VAV\"\xc7\x02\n\x06\x44\x61mper\x12\x7f\n\x17\x64\x61mper_position_command\x18\x01 \x01(\x0b\x32\x0e.xbospb.DoubleBN\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\x19\x12\x17\x44\x61mper_Position_Command\x12}\n\x16\x64\x61mper_position_sensor\x18\x02 \x01(\x0b\x32\x0e.xbospb.DoubleBM\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\x18\x12\x16\x44\x61mper_Position_Sensor:=\x82\xf1\x04-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xf1\x04\x08\x12\x06\x44\x61mper\"\xdf\x05\n\x03\x46\x61n\x12m\n\x0eon_off_command\x18\x01 \x01(\x0b\x32\x0e.xbospb.DoubleBE\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\x10\x12\x0eOn_Off_Command\x12u\n\x12\x66\x61n_speed_setpoint\x18\x02 \x01(\x0b\x32\x0e.xbospb.DoubleBI\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\x14\x12\x12\x46\x61n_Speed_Setpoint\x12s\n\x11\x66\x61n_reset_command\x18\x03 \x01(\x0b\x32\x0e.xbospb.DoubleBH\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\x13\x12\x11\x46\x61n_Reset_Command\x12u\n\x12\x66\x61n_overload_alarm\x18\x04 \x01(\x0b\x32\x0e.xbospb.DoubleBI\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\x14\x12\x12\x46\x61n_Overload_Alarm\x12\x63\n\tvfd_alarm\x18\x05 \x01(\x0b\x32\x0e.xbospb.DoubleB@\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\x0b\x12\tVFD_Alarm\x12\x65\n\nfan_status\x18\x06 \x01(\x0b\x32\x0e.xbospb.DoubleBA\x82\xb5\x18-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xb5\x18\x0c\x12\nFan_Status::\x82\xf1\x04-\n+https://brickschema.org/schema/1.0.3/Brick#\x82\xf1\x04\x05\x12\x03\x46\x61nb\x06proto3')
  ,
  dependencies=[brick__pb2.DESCRIPTOR,nullabletypes__pb2.DESCRIPTOR,])




_AHU = _descriptor.Descriptor(
  name='AHU',
  full_name='xbospb.AHU',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='discharge_air_temperature_setpoint', full_name='xbospb.AHU.discharge_air_temperature_setpoint', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030$\022\"Discharge_Air_Temperature_Setpoint'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outside_air_temperature_sensor', full_name='xbospb.AHU.outside_air_temperature_sensor', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030 \022\036Outside_Air_Temperature_Sensor'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='heating_valve_command', full_name='xbospb.AHU.heating_valve_command', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030\027\022\025Heating_Valve_Command'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='discharge_air_static_pressure_sensor', full_name='xbospb.AHU.discharge_air_static_pressure_sensor', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030&\022$Discharge_Air_Static_Pressure_Sensor'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cooling_demand', full_name='xbospb.AHU.cooling_demand', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030\020\022\016Cooling_Demand'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cooling_valve_command', full_name='xbospb.AHU.cooling_valve_command', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030\027\022\025Cooling_Valve_Command'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_air_temperature_sensor', full_name='xbospb.AHU.mixed_air_temperature_sensor', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030\036\022\034Mixed_Air_Temperature_Sensor'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='building_static_pressure_sensor', full_name='xbospb.AHU.building_static_pressure_sensor', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030!\022\037Building_Static_Pressure_Sensor'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filter_status', full_name='xbospb.AHU.filter_status', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030\017\022\rFilter_Status'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='discharge_air_temperature_sensor', full_name='xbospb.AHU.discharge_air_temperature_sensor', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030\"\022 Discharge_Air_Temperature_Sensor'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='building_static_pressure_setpoint', full_name='xbospb.AHU.building_static_pressure_setpoint', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030#\022!Building_Static_Pressure_Setpoint'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='discharge_air_static_pressure_setpoint', full_name='xbospb.AHU.discharge_air_static_pressure_setpoint', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030(\022&Discharge_Air_Static_Pressure_Setpoint'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='occupancy_command', full_name='xbospb.AHU.occupancy_command', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030\023\022\021Occupancy_Command'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='return_air_temperature_sensor', full_name='xbospb.AHU.return_air_temperature_sensor', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030\037\022\035Return_Air_Temperature_Sensor'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='zone_temperature_sensor', full_name='xbospb.AHU.zone_temperature_sensor', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030\031\022\027Zone_Temperature_Sensor'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='supply_air_damper_min_position_setpoint', full_name='xbospb.AHU.supply_air_damper_min_position_setpoint', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030)\022\'Supply_Air_Damper_Min_Position_Setpoint'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_air_temperature_setpoint', full_name='xbospb.AHU.mixed_air_temperature_setpoint', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030 \022\036Mixed_Air_Temperature_Setpoint'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='occupied_mode_status', full_name='xbospb.AHU.occupied_mode_status', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030\026\022\024Occupied_Mode_Status'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shutdown_command', full_name='xbospb.AHU.shutdown_command', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030\022\022\020Shutdown_Command'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_air_temperature_low_limit_setpoint', full_name='xbospb.AHU.mixed_air_temperature_low_limit_setpoint', index=19,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030*\022(Mixed_Air_Temperature_Low_Limit_Setpoint'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='zone_temperature_setpoint', full_name='xbospb.AHU.zone_temperature_setpoint', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030\033\022\031Zone_Temperature_Setpoint'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vav', full_name='xbospb.AHU.vav', index=21,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030\005\022\003VAV'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vvt', full_name='xbospb.AHU.vvt', index=22,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030\005\022\003VVT'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\202\361\004-\n+https://brickschema.org/schema/1.0.3/Brick#\202\361\004\005\022\003AHU'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=57,
  serialized_end=3196,
)


_ECONOMIZER = _descriptor.Descriptor(
  name='Economizer',
  full_name='xbospb.Economizer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='economizer_differential_air_temperature_setpoint', full_name='xbospb.Economizer.economizer_differential_air_temperature_setpoint', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\0302\0220Economizer_Differential_Air_Temperature_Setpoint'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\202\361\004-\n+https://brickschema.org/schema/1.0.3/Brick#\202\361\004\014\022\nEconomizer'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3199,
  serialized_end=3458,
)


_VAV = _descriptor.Descriptor(
  name='VAV',
  full_name='xbospb.VAV',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='zone_temperature_setpoint', full_name='xbospb.VAV.zone_temperature_setpoint', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030\033\022\031Zone_Temperature_Setpoint'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='occupied_heating_min_supply_air_flow_setpoint', full_name='xbospb.VAV.occupied_heating_min_supply_air_flow_setpoint', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030/\022-Occupied_Heating_Min_Supply_Air_Flow_Setpoint'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='supply_air_flow_setpoint', full_name='xbospb.VAV.supply_air_flow_setpoint', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030\032\022\030Supply_Air_Flow_Setpoint'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='discharge_air_temperature_sensor', full_name='xbospb.VAV.discharge_air_temperature_sensor', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030\"\022 Discharge_Air_Temperature_Sensor'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='heating_demand', full_name='xbospb.VAV.heating_demand', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030\020\022\016Heating_Demand'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='box_mode', full_name='xbospb.VAV.box_mode', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030\n\022\010Box_Mode'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cooling_demand', full_name='xbospb.VAV.cooling_demand', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030\020\022\016Cooling_Demand'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='supply_air_velocity_pressure_sensor', full_name='xbospb.VAV.supply_air_velocity_pressure_sensor', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030%\022#Supply_Air_Velocity_Pressure_Sensor'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cooling_max_supply_air_flow_setpoint', full_name='xbospb.VAV.cooling_max_supply_air_flow_setpoint', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030&\022$Cooling_Max_Supply_Air_Flow_Setpoint'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thermostat_adjust_setpoint', full_name='xbospb.VAV.thermostat_adjust_setpoint', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030\034\022\032Thermostat_Adjust_Setpoint'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='zone_temperature_sensor', full_name='xbospb.VAV.zone_temperature_sensor', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030\031\022\027Zone_Temperature_Sensor'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='supply_air_flow_sensor', full_name='xbospb.VAV.supply_air_flow_sensor', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030\030\022\026Supply_Air_Flow_Sensor'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\202\361\004-\n+https://brickschema.org/schema/1.0.3/Brick#\202\361\004\005\022\003VAV'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3461,
  serialized_end=5137,
)


_DAMPER = _descriptor.Descriptor(
  name='Damper',
  full_name='xbospb.Damper',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='damper_position_command', full_name='xbospb.Damper.damper_position_command', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030\031\022\027Damper_Position_Command'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='damper_position_sensor', full_name='xbospb.Damper.damper_position_sensor', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030\030\022\026Damper_Position_Sensor'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\202\361\004-\n+https://brickschema.org/schema/1.0.3/Brick#\202\361\004\010\022\006Damper'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5140,
  serialized_end=5467,
)


_FAN = _descriptor.Descriptor(
  name='Fan',
  full_name='xbospb.Fan',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='on_off_command', full_name='xbospb.Fan.on_off_command', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030\020\022\016On_Off_Command'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fan_speed_setpoint', full_name='xbospb.Fan.fan_speed_setpoint', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030\024\022\022Fan_Speed_Setpoint'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fan_reset_command', full_name='xbospb.Fan.fan_reset_command', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030\023\022\021Fan_Reset_Command'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fan_overload_alarm', full_name='xbospb.Fan.fan_overload_alarm', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030\024\022\022Fan_Overload_Alarm'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vfd_alarm', full_name='xbospb.Fan.vfd_alarm', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030\013\022\tVFD_Alarm'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fan_status', full_name='xbospb.Fan.fan_status', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030-\n+https://brickschema.org/schema/1.0.3/Brick#\202\265\030\014\022\nFan_Status'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\202\361\004-\n+https://brickschema.org/schema/1.0.3/Brick#\202\361\004\005\022\003Fan'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5470,
  serialized_end=6205,
)

_AHU.fields_by_name['discharge_air_temperature_setpoint'].message_type = nullabletypes__pb2._DOUBLE
_AHU.fields_by_name['outside_air_temperature_sensor'].message_type = nullabletypes__pb2._DOUBLE
_AHU.fields_by_name['heating_valve_command'].message_type = nullabletypes__pb2._DOUBLE
_AHU.fields_by_name['discharge_air_static_pressure_sensor'].message_type = nullabletypes__pb2._DOUBLE
_AHU.fields_by_name['cooling_demand'].message_type = nullabletypes__pb2._DOUBLE
_AHU.fields_by_name['cooling_valve_command'].message_type = nullabletypes__pb2._DOUBLE
_AHU.fields_by_name['mixed_air_temperature_sensor'].message_type = nullabletypes__pb2._DOUBLE
_AHU.fields_by_name['building_static_pressure_sensor'].message_type = nullabletypes__pb2._DOUBLE
_AHU.fields_by_name['filter_status'].message_type = nullabletypes__pb2._DOUBLE
_AHU.fields_by_name['discharge_air_temperature_sensor'].message_type = nullabletypes__pb2._DOUBLE
_AHU.fields_by_name['building_static_pressure_setpoint'].message_type = nullabletypes__pb2._DOUBLE
_AHU.fields_by_name['discharge_air_static_pressure_setpoint'].message_type = nullabletypes__pb2._DOUBLE
_AHU.fields_by_name['occupancy_command'].message_type = nullabletypes__pb2._DOUBLE
_AHU.fields_by_name['return_air_temperature_sensor'].message_type = nullabletypes__pb2._DOUBLE
_AHU.fields_by_name['zone_temperature_sensor'].message_type = nullabletypes__pb2._DOUBLE
_AHU.fields_by_name['supply_air_damper_min_position_setpoint'].message_type = nullabletypes__pb2._DOUBLE
_AHU.fields_by_name['mixed_air_temperature_setpoint'].message_type = nullabletypes__pb2._DOUBLE
_AHU.fields_by_name['occupied_mode_status'].message_type = nullabletypes__pb2._DOUBLE
_AHU.fields_by_name['shutdown_command'].message_type = nullabletypes__pb2._DOUBLE
_AHU.fields_by_name['mixed_air_temperature_low_limit_setpoint'].message_type = nullabletypes__pb2._DOUBLE
_AHU.fields_by_name['zone_temperature_setpoint'].message_type = nullabletypes__pb2._DOUBLE
_AHU.fields_by_name['vav'].message_type = nullabletypes__pb2._DOUBLE
_AHU.fields_by_name['vvt'].message_type = nullabletypes__pb2._DOUBLE
_ECONOMIZER.fields_by_name['economizer_differential_air_temperature_setpoint'].message_type = nullabletypes__pb2._DOUBLE
_VAV.fields_by_name['zone_temperature_setpoint'].message_type = nullabletypes__pb2._DOUBLE
_VAV.fields_by_name['occupied_heating_min_supply_air_flow_setpoint'].message_type = nullabletypes__pb2._DOUBLE
_VAV.fields_by_name['supply_air_flow_setpoint'].message_type = nullabletypes__pb2._DOUBLE
_VAV.fields_by_name['discharge_air_temperature_sensor'].message_type = nullabletypes__pb2._DOUBLE
_VAV.fields_by_name['heating_demand'].message_type = nullabletypes__pb2._DOUBLE
_VAV.fields_by_name['box_mode'].message_type = nullabletypes__pb2._DOUBLE
_VAV.fields_by_name['cooling_demand'].message_type = nullabletypes__pb2._DOUBLE
_VAV.fields_by_name['supply_air_velocity_pressure_sensor'].message_type = nullabletypes__pb2._DOUBLE
_VAV.fields_by_name['cooling_max_supply_air_flow_setpoint'].message_type = nullabletypes__pb2._DOUBLE
_VAV.fields_by_name['thermostat_adjust_setpoint'].message_type = nullabletypes__pb2._DOUBLE
_VAV.fields_by_name['zone_temperature_sensor'].message_type = nullabletypes__pb2._DOUBLE
_VAV.fields_by_name['supply_air_flow_sensor'].message_type = nullabletypes__pb2._DOUBLE
_DAMPER.fields_by_name['damper_position_command'].message_type = nullabletypes__pb2._DOUBLE
_DAMPER.fields_by_name['damper_position_sensor'].message_type = nullabletypes__pb2._DOUBLE
_FAN.fields_by_name['on_off_command'].message_type = nullabletypes__pb2._DOUBLE
_FAN.fields_by_name['fan_speed_setpoint'].message_type = nullabletypes__pb2._DOUBLE
_FAN.fields_by_name['fan_reset_command'].message_type = nullabletypes__pb2._DOUBLE
_FAN.fields_by_name['fan_overload_alarm'].message_type = nullabletypes__pb2._DOUBLE
_FAN.fields_by_name['vfd_alarm'].message_type = nullabletypes__pb2._DOUBLE
_FAN.fields_by_name['fan_status'].message_type = nullabletypes__pb2._DOUBLE
DESCRIPTOR.message_types_by_name['AHU'] = _AHU
DESCRIPTOR.message_types_by_name['Economizer'] = _ECONOMIZER
DESCRIPTOR.message_types_by_name['VAV'] = _VAV
DESCRIPTOR.message_types_by_name['Damper'] = _DAMPER
DESCRIPTOR.message_types_by_name['Fan'] = _FAN
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AHU = _reflection.GeneratedProtocolMessageType('AHU', (_message.Message,), dict(
  DESCRIPTOR = _AHU,
  __module__ = 'hvac_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.AHU)
  ))
_sym_db.RegisterMessage(AHU)

Economizer = _reflection.GeneratedProtocolMessageType('Economizer', (_message.Message,), dict(
  DESCRIPTOR = _ECONOMIZER,
  __module__ = 'hvac_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.Economizer)
  ))
_sym_db.RegisterMessage(Economizer)

VAV = _reflection.GeneratedProtocolMessageType('VAV', (_message.Message,), dict(
  DESCRIPTOR = _VAV,
  __module__ = 'hvac_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.VAV)
  ))
_sym_db.RegisterMessage(VAV)

Damper = _reflection.GeneratedProtocolMessageType('Damper', (_message.Message,), dict(
  DESCRIPTOR = _DAMPER,
  __module__ = 'hvac_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.Damper)
  ))
_sym_db.RegisterMessage(Damper)

Fan = _reflection.GeneratedProtocolMessageType('Fan', (_message.Message,), dict(
  DESCRIPTOR = _FAN,
  __module__ = 'hvac_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.Fan)
  ))
_sym_db.RegisterMessage(Fan)


_AHU.fields_by_name['discharge_air_temperature_setpoint']._options = None
_AHU.fields_by_name['outside_air_temperature_sensor']._options = None
_AHU.fields_by_name['heating_valve_command']._options = None
_AHU.fields_by_name['discharge_air_static_pressure_sensor']._options = None
_AHU.fields_by_name['cooling_demand']._options = None
_AHU.fields_by_name['cooling_valve_command']._options = None
_AHU.fields_by_name['mixed_air_temperature_sensor']._options = None
_AHU.fields_by_name['building_static_pressure_sensor']._options = None
_AHU.fields_by_name['filter_status']._options = None
_AHU.fields_by_name['discharge_air_temperature_sensor']._options = None
_AHU.fields_by_name['building_static_pressure_setpoint']._options = None
_AHU.fields_by_name['discharge_air_static_pressure_setpoint']._options = None
_AHU.fields_by_name['occupancy_command']._options = None
_AHU.fields_by_name['return_air_temperature_sensor']._options = None
_AHU.fields_by_name['zone_temperature_sensor']._options = None
_AHU.fields_by_name['supply_air_damper_min_position_setpoint']._options = None
_AHU.fields_by_name['mixed_air_temperature_setpoint']._options = None
_AHU.fields_by_name['occupied_mode_status']._options = None
_AHU.fields_by_name['shutdown_command']._options = None
_AHU.fields_by_name['mixed_air_temperature_low_limit_setpoint']._options = None
_AHU.fields_by_name['zone_temperature_setpoint']._options = None
_AHU.fields_by_name['vav']._options = None
_AHU.fields_by_name['vvt']._options = None
_AHU._options = None
_ECONOMIZER.fields_by_name['economizer_differential_air_temperature_setpoint']._options = None
_ECONOMIZER._options = None
_VAV.fields_by_name['zone_temperature_setpoint']._options = None
_VAV.fields_by_name['occupied_heating_min_supply_air_flow_setpoint']._options = None
_VAV.fields_by_name['supply_air_flow_setpoint']._options = None
_VAV.fields_by_name['discharge_air_temperature_sensor']._options = None
_VAV.fields_by_name['heating_demand']._options = None
_VAV.fields_by_name['box_mode']._options = None
_VAV.fields_by_name['cooling_demand']._options = None
_VAV.fields_by_name['supply_air_velocity_pressure_sensor']._options = None
_VAV.fields_by_name['cooling_max_supply_air_flow_setpoint']._options = None
_VAV.fields_by_name['thermostat_adjust_setpoint']._options = None
_VAV.fields_by_name['zone_temperature_sensor']._options = None
_VAV.fields_by_name['supply_air_flow_sensor']._options = None
_VAV._options = None
_DAMPER.fields_by_name['damper_position_command']._options = None
_DAMPER.fields_by_name['damper_position_sensor']._options = None
_DAMPER._options = None
_FAN.fields_by_name['on_off_command']._options = None
_FAN.fields_by_name['fan_speed_setpoint']._options = None
_FAN.fields_by_name['fan_reset_command']._options = None
_FAN.fields_by_name['fan_overload_alarm']._options = None
_FAN.fields_by_name['vfd_alarm']._options = None
_FAN.fields_by_name['fan_status']._options = None
_FAN._options = None
# @@protoc_insertion_point(module_scope)
